package Daje::Plugin::Mail::Helpers;
use Mojo::Base -base, -signatures;
use v5.42;

# NAME
# ====
#
# Daje::Plugin::Mail::Helpers - Model class
#
# SYNOPSIS
# ========
#
#       use Daje::Plugin::Mail::Helpers;
#
#       my $class = Daje::Plugin::Mail::Helpers->new();
#       $app->helper(
#           v_mail_mails => sub {
#               state  $v_mail_mails = Daje::Database::Model::vMailMails->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_mail_attachements => sub {
#               state  $v_mail_attachements = Daje::Database::Model::vMailAttachements->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_mail_status => sub {
#               state  $v_mail_status = Daje::Database::Model::vMailStatus->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_mail_settings => sub {
#               state  $v_mail_settings = Daje::Database::Model::vMailSettings->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_mail_fallback_settings => sub {
#               state  $v_mail_fallback_settings = Daje::Database::Model::vMailFallbackSettings->new(db => shift->pg->db)
#        });#
#       $app->helper(
#           v_mail_mails_list => sub {
#               state  $v_mail_mails_list = Daje::Database::Model::vMailMailsList->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_mail_attachements_list => sub {
#               state  $v_mail_attachements_list = Daje::Database::Model::vMailAttachementsList->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_mail_status_list => sub {
#               state  $v_mail_status_list = Daje::Database::Model::vMailStatusList->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_mail_settings_list => sub {
#               state  $v_mail_settings_list = Daje::Database::Model::vMailSettingsList->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_mail_fallback_settings_list => sub {
#               state  $v_mail_fallback_settings_list = Daje::Database::Model::vMailFallbackSettingsList->new(db => shift->pg->db)
#        });#
# DESCRIPTION
# ===========
#
# Daje::Plugin::Mail::Helpers is the standard routes
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-02-13 15:59:43.
# It will be re-generated by Daje Tools again.
# <!-- Autogenerated file 2026-02-13 15:59:43 -->

use Daje::Database::View::vMailMails;
use Daje::Database::View::vMailAttachements;
use Daje::Database::View::vMailStatus;
use Daje::Database::View::vMailSettings;
use Daje::Database::View::vMailFallbackSettings;# Lists
use Daje::Database::View::vMailMailsList;
use Daje::Database::View::vMailAttachementsList;
use Daje::Database::View::vMailStatusList;
use Daje::Database::View::vMailSettingsList;
use Daje::Database::View::vMailFallbackSettingsList;

our $VERSION = '0.01';

sub helpers($self, $app, $config) {

    $app->helper(
        v_mail_mails => sub {
            state  $v_mail_mails = Daje::Database::View::vMailMails->new(db => shift->pg->db)
        });
    $app->helper(
        v_mail_attachements => sub {
            state  $v_mail_attachements = Daje::Database::View::vMailAttachements->new(db => shift->pg->db)
        });
    $app->helper(
        v_mail_status => sub {
            state  $v_mail_status = Daje::Database::View::vMailStatus->new(db => shift->pg->db)
        });
    $app->helper(
        v_mail_settings => sub {
            state  $v_mail_settings = Daje::Database::View::vMailSettings->new(db => shift->pg->db)
        });
    $app->helper(
        v_mail_fallback_settings => sub {
            state  $v_mail_fallback_settings = Daje::Database::View::vMailFallbackSettings->new(db => shift->pg->db)
        });    # Lists
    $app->helper(
        v_mail_mails_list => sub {
            state  $v_mail_mails_list = Daje::Database::View::vMailMailsList->new(db => shift->pg->db)
        });
    $app->helper(
        v_mail_attachements_list => sub {
            state  $v_mail_attachements_list = Daje::Database::View::vMailAttachementsList->new(db => shift->pg->db)
        });
    $app->helper(
        v_mail_status_list => sub {
            state  $v_mail_status_list = Daje::Database::View::vMailStatusList->new(db => shift->pg->db)
        });
    $app->helper(
        v_mail_settings_list => sub {
            state  $v_mail_settings_list = Daje::Database::View::vMailSettingsList->new(db => shift->pg->db)
        });
    $app->helper(
        v_mail_fallback_settings_list => sub {
            state  $v_mail_fallback_settings_list = Daje::Database::View::vMailFallbackSettingsList->new(db => shift->pg->db)
        });}

1;



