package Daje::Database::View::Super::vMailStatusList;
use Mojo::Base 'Daje::Database::Model::Super::Common::Base', -base, -signatures, -async_await;
use v5.42;

# NAME
# ====
#
# Daje::Database::View::Super::vMailStatusList - Daje db view
#
# SYNOPSIS
# ========
#
#
#       use Daje::Database::View::Super::vMailStatusList;
#
#       my $table = Daje::Database::View::Super::vMailStatusList->new(db => $db);
#
#       my $result = $table->load_mail_status_pkey($self, $mail_status_pkey);
#
#       my $result = $table->load_mail_companies_fkey($self, $mail_companies_fkey);
##
#       my $result = $table->insert($self, $data);
#
#       $table->update($self, $data) ;
#
#
# DESCRIPTION
# ===========
#
# Daje::Database::View::Super::MailStatusList is a Model super class
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-02-13 15:59:43.
# It will be re-created by Daje Tools again and any changes
# will be over written.
#
# <!-- Autogenerated file 2026-02-13 15:59:43 -->

our $VERSION = '0.01';

has 'fields' => '"mail_status_pkey", "editnum", "insby", "insdatetime", "modby", "moddatetime","status","description",
"companies_companies_fkey"';
has 'primary_key_name' => "mail_status_pkey";
has 'table_name' => "v_mail_status_list";

async sub load_all_companies_companies_list_p($self) {
    return $self->load_all_companies_companies_list();
}

sub load_all_companies_companies_list($self) {
    return $self->load_a_full_list(
        $self->table_name, $self->fields()
    );
}

async sub load_companies_companies_list_p($self, $key_value) {
    return $self->load_mail_companies_list($key_value);
}

sub load_companies_companies_list($self, $key_value) {
    return $self->load_a_list(
        $self->table_name, $self->fields(), $key_value
    );
}
async sub load_all_mail_status_p($self) {
    return $self->load_all_mail_status();
}

sub load_all_mail_status($self) {
    return $self->load_a_full_list(
        $self->table_name, $self->fields()
    );
}
1;


