package Daje::Database::View::Super::vMailFallbackSettingsList;
use Mojo::Base 'Daje::Database::Model::Super::Common::Base', -base, -signatures, -async_await;
use v5.42;

# NAME
# ====
#
# Daje::Database::View::Super::vMailFallbackSettingsList - Daje db view
#
# SYNOPSIS
# ========
#
#
#       use Daje::Database::View::Super::vMailFallbackSettingsList;
#
#       my $table = Daje::Database::View::Super::vMailFallbackSettingsList->new(db => $db);
#
#       my $result = $table->load_mail_fallback_settings_pkey($self, $mail_fallback_settings_pkey);
##
#       my $result = $table->insert($self, $data);
#
#       $table->update($self, $data) ;
#
#
# DESCRIPTION
# ===========
#
# Daje::Database::View::Super::MailFallbackSettingsList is a Model super class
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-02-13 15:59:43.
# It will be re-created by Daje Tools again and any changes
# will be over written.
#
# <!-- Autogenerated file 2026-02-13 15:59:43 -->

our $VERSION = '0.01';

has 'fields' => '"mail_fallback_settings_pkey", "editnum", "insby", "insdatetime", "modby", "moddatetime","host","port","username","password"';
has 'primary_key_name' => "mail_fallback_settings_pkey";
has 'table_name' => "v_mail_fallback_settings_list";

async sub load_all_mail_fallback_settings_p($self) {
    return $self->load_all_mail_fallback_settings();
}

sub load_all_mail_fallback_settings($self) {
    return $self->load_a_full_list(
        $self->table_name, $self->fields()
    );
}
1;


