package Daje::Plugin::Mail::Routes;
use Mojo::Base -base, -signatures;
use v5.42;

# NAME
# ====
#
# Daje::Plugin::Mail::Routes - Model class
#
# SYNOPSIS
# ========
#
#       use Daje::Plugin::Mail::Routes;
#
#       my $class = Daje::Plugin::Mail::Routes->new();
#       $r->get('/mail/api/v1/mails/:mail_mails_pkey');
#       $r->get('/mail/api/v1/mails_companies/:mail_companies_fkey');

       
#       $r->get('/mail/api/v1/mails_users/:mail_users_fkey');

       
#       $r->get('/mail/api/v1/mails_status/:mail_status_fkey');

       
#       $r->get('/mail/api/v1/attachements/:mail_attachements_pkey');
#       $r->get('/mail/api/v1/attachements_mails/:mail_mails_fkey');

       
#       $r->get('/mail/api/v1/status/:mail_status_pkey');
#       $r->get('/mail/api/v1/status_companies/:mail_companies_fkey');

       
#       $r->get('/mail/api/v1/settings/:mail_settings_pkey');
#       $r->get('/mail/api/v1/settings_companies/:mail_companies_fkey');

       
#       $r->get('/mail/api/v1/fallback_settings/:mail_fallback_settings_pkey');#
#
# DESCRIPTION
# ===========
#
# Daje::Plugin::Mail::Routes is the standard routes
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-02-13 15:59:43.
# It will be generated by Daje Tools again.
# <!-- Autogenerated file 2026-02-13 15:59:43 -->

our $VERSION = '0.01';

sub routes($self, $app, $config) {
    my $r = $app->auth;

    $r->get('v1/mails_list_all/')->to('MailMailsList#load_all_mail_mails');
    $r->get('v1/mails_companies_list/:companies_companies_fkey')->to('MailMails#load_list_companies_companies_fkey');
    $r->get('v1/mails_users_list/:users_users_fkey')->to('MailMails#load_list_users_users_fkey');
    $r->get('v1/mails_status_list/:mail_status_fkey')->to('MailMails#load_list_mail_status_fkey');
    $r->get('v1/attachements_list_all/')->to('MailAttachementsList#load_all_mail_attachements');
    $r->get('v1/attachements_mails_list/:mail_mails_fkey')->to('MailAttachements#load_list_mail_mails_fkey');
    $r->get('v1/status_list_all/')->to('MailStatusList#load_all_mail_status');
    $r->get('v1/status_companies_list/:companies_companies_fkey')->to('MailStatus#load_list_companies_companies_fkey');
    $r->get('v1/settings_list_all/')->to('MailSettingsList#load_all_mail_settings');
    $r->get('v1/settings_companies_list/:companies_companies_fkey')->to('MailSettings#load_list_companies_companies_fkey');
    $r->get('v1/fallback_settings_list_all/')->to('MailFallbackSettingsList#load_all_mail_fallback_settings');

    $r->get('v1/mails_companies/:mail_companies_fkey')->to('MailMails#load_mail_companies_fkey');
    $r->get('v1/mails_users/:mail_users_fkey')->to('MailMails#load_mail_users_fkey');
    $r->get('v1/mails_status/:mail_status_fkey')->to('MailMails#load_mail_status_fkey');    $r->get('v1/mails/:mail_mails_pkey')->to('MailMails#load_mail_mails_pkey');
    $r->get('v1/attachements_mails/:mail_mails_fkey')->to('MailAttachements#load_mail_mails_fkey');    $r->get('v1/attachements/:mail_attachements_pkey')->to('MailAttachements#load_mail_attachements_pkey');
    $r->get('v1/status_companies/:mail_companies_fkey')->to('MailStatus#load_mail_companies_fkey');    $r->get('v1/status/:mail_status_pkey')->to('MailStatus#load_mail_status_pkey');
    $r->get('v1/settings_companies/:mail_companies_fkey')->to('MailSettings#load_mail_companies_fkey');    $r->get('v1/settings/:mail_settings_pkey')->to('MailSettings#load_mail_settings_pkey');    $r->get('v1/fallback_settings/:mail_fallback_settings_pkey')->to('MailFallbackSettings#load_mail_fallback_settings_pkey');
}

